@@ -162,7 +162,7 @@ static gboolean pp_get_fullscreen (ClutterStage *stage)
 static void
 _destroy_surface (gpointer data)
 {
-  /* not destroying background, since it would be destoryed with
+  /* not destroying background, since it would be destroyed with
    * the stage itself.
    */
 }
@@ -400,7 +400,7 @@ _clutter_get_texture (ClutterRenderer *renderer,
   clutter_container_add_actor (CLUTTER_CONTAINER (renderer->stage), source);
   clutter_actor_hide (source);
 
-  g_hash_table_insert (renderer->bg_cache, (char *) file, source);
+  g_hash_table_insert (renderer->bg_cache, (char *) g_strdup (file), source);
 
   return clutter_clone_new (source);
 }
@@ -412,9 +412,20 @@ clutter_renderer_make_point (PinPointRenderer *pp_renderer,
 {
   ClutterRenderer *renderer = CLUTTER_RENDERER (pp_renderer);
   ClutterPointData *data = point->data;
+  const gchar *file = point->bg;
+  gchar *full_path = NULL;
   ClutterColor color;
   gboolean ret;
 
+  if (point->bg_type != PP_BG_COLOR && renderer->path && file)
+    {
+      gchar *dir = g_path_get_dirname (renderer->path);
+      full_path = g_build_filename (dir, file, NULL);
+      g_free (dir);
+
+      file = full_path;
+    }
+
   switch (point->bg_type)
     {
     case PP_BG_COLOR:
@@ -429,13 +440,13 @@ clutter_renderer_make_point (PinPointRenderer *pp_renderer,
       }
       break;
     case PP_BG_IMAGE:
-      data->background = _clutter_get_texture (renderer, point->bg);
+      data->background = _clutter_get_texture (renderer, file);
       ret = TRUE;
       break;
     case PP_BG_VIDEO:
 #ifdef USE_CLUTTER_GST
       data->background = clutter_gst_video_texture_new ();
-      clutter_media_set_filename (CLUTTER_MEDIA (data->background), point->bg);
+      clutter_media_set_filename (CLUTTER_MEDIA (data->background), file);
       /* should pre-roll the video and set the size */
       clutter_actor_set_size (data->background, 400, 300);
       ret = TRUE;
@@ -449,7 +460,7 @@ clutter_renderer_make_point (PinPointRenderer *pp_renderer,
 
         aa = pp_super_aa_new ();
         pp_super_aa_set_resolution (PP_SUPER_AA (aa), 2, 2);
-        svg = dax_actor_new_from_file (point->bg, &error);
+        svg = dax_actor_new_from_file (file, &error);
         mx_offscreen_set_pick_child (MX_OFFSCREEN (aa), TRUE);
         clutter_container_add_actor (CLUTTER_CONTAINER (aa),
                                      svg);
@@ -459,7 +470,7 @@ clutter_renderer_make_point (PinPointRenderer *pp_renderer,
         if (data->background == NULL)
           {
             g_warning ("Could not open SVG file %s: %s",
-                       point->bg, error->message);
+                       file, error->message);
             g_clear_error (&error);
           }
         ret = data->background != NULL;
@@ -470,6 +481,8 @@ clutter_renderer_make_point (PinPointRenderer *pp_renderer,
       g_assert_not_reached();
     }
 
+  g_free (full_path);
+
   if (data->background)
     {
       clutter_container_add_actor (CLUTTER_CONTAINER (renderer->background),
@@ -768,7 +781,7 @@ show_slide (ClutterRenderer *renderer, gboolean backwards)
 
   if (data->background)
     {
-      float bg_x, bg_y, bg_width, bg_height, bg_scale;
+      float bg_x, bg_y, bg_width, bg_height, bg_scale_x, bg_scale_y;
       if (CLUTTER_IS_RECTANGLE (data->background))
         {
           clutter_actor_get_size (renderer->stage, &bg_width, &bg_height);
@@ -783,9 +796,9 @@ show_slide (ClutterRenderer *renderer, gboolean backwards)
                                         clutter_actor_get_width (renderer->stage),
                                         clutter_actor_get_height (renderer->stage),
                                         bg_width, bg_height,
-                                        &bg_x, &bg_y, &bg_scale);
+                                        &bg_x, &bg_y, &bg_scale_x, &bg_scale_y);
 
-      clutter_actor_set_scale (data->background, bg_scale, bg_scale);
+      clutter_actor_set_scale (data->background, bg_scale_x, bg_scale_y);
       clutter_actor_set_position (data->background, bg_x, bg_y);
 
 #ifdef USE_CLUTTER_GST
